pub enum StepError {
    Halt(ExpTerm),
    Stuck(Stuck),
}
Cases for which step fails to reduce the program

Variants

Halt(ExpTerm)

Ordinary program termination

Though a “step error” (step cannot reduce the configuration), this outcome signals ordinary termination of the program. In particular, step cannot reduce a terminal expression in a configuration with an empty stack: there are no continuations to follow; these configurations have “halted” (terminated).

Stuck(Stuck)

Irreducible, ill-typed program configurations

All other errors (aside from an empty stack) are unexpected in a well-typed Fungi program, and correspond to reduction getting “stuck” in a state that is not well-typed.